@@ -1,7 +1,7 @@
 package Finance::BTCIndo;
 
 our $DATE = '2017-05-31'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -201,7 +201,7 @@ Finance::BTCIndo - Trade with bitcoin.co.id (VIP) using Perl
 
 =head1 VERSION
 
-This document describes version 0.002 of Finance::BTCIndo (from Perl distribution Finance-BTCIndo), released on 2017-05-31.
+This document describes version 0.003 of Finance::BTCIndo (from Perl distribution Finance-BTCIndo), released on 2017-05-31.
 
 =head1 SYNOPSIS
 
@@ -481,6 +481,9 @@ feature.
 API documentation,
 L<https://blog.bitcoin.co.id/wp-content/uploads/2014/03/API-Documentation-Bitcoin.co_.id_.pdf>
 
+CLI that uses this module, for more convenience daily usage on the command-line:
+L<btcindo> (from L<App::btcindo> distribution).
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
